@@ -9,9 +9,7 @@ from botx.typing import BotLifespanEvent
 try:
     from typing import Protocol  # noqa: WPS433
 except ImportError:
-    from typing_extensions import (  # type: ignore  # noqa: WPS433, WPS440, F401
-        Protocol,
-    )
+    from typing_extensions import Protocol  # type: ignore  # noqa: WPS433, WPS440, F401
 
 
 class LifespanMixin:
